@@ -8,12 +8,11 @@ import shutil
 import sys
 from typing import Any, Generator, List, Optional, Union
 
-import junit_xml  # type: ignore
-
-from yea import context, ytest
+from yea import context, util, ytest
 
 
 logger = logging.getLogger(__name__)
+junit_xml = util.vendor_import("wandb_junit_xml")
 
 
 def convert(text: str) -> Union[int, str]:
@@ -34,7 +33,8 @@ class TestRunner:
         self.prepare()
         self._args = yc._args
         self._test_files: List[str] = []
-        self._results: List[junit_xml.TestCase] = []
+        # self._results: List[junit_xml.TestCase] = []
+        self._results: List = []
         self._test_list: List["ytest.YeaTest"] = []
 
     def prepare(self) -> None:
@@ -108,9 +108,19 @@ class TestRunner:
         test_cfg = t._test_cfg
         if not test_cfg:
             return
-        result = self._yc.test_check(t)
+        result_list = self._yc.test_check(t)
+
+        failures = []
+        state = {}
+        for result in result_list:
+            if result.failures:
+                failures.extend(result.failures)
+            if result._state:
+                state.update(result._state)
+
         # print("GOTRES", result)
-        result_str = ",".join(result)
+        result_str = ",".join(failures)
+        profile_dict = state.get(":yea:profile")
         # self._results[t._tname] = result_str
         if t._time_end is None or t._time_start is None:
             raise RuntimeError("Test not run")
@@ -118,6 +128,10 @@ class TestRunner:
         tc = junit_xml.TestCase(t.test_id, classname="yea_func", elapsed_sec=elapsed)
         if result_str:
             tc.add_failure_info(message=result_str)
+        if profile_dict:
+            for metric, stats in profile_dict.items():
+                for stat, value in stats.items():
+                    tc.add_property(name=f"{metric}::{stat}", value=value)
         self._results.append(tc)
 
     def run(self, tests: List["ytest.YeaTest"]) -> None:
